Learn R Programming

HDXBoxeR (version 0.0.2)

qpcr.cbind.na: Hidden function from qpcR package, typical usage as qpcR:::cbind.na

Description

Combine data of unequal row length avoiding repetition or errors by filling with NAs. In contrast to classical cbind, cbind.na can be used to combine data such as

Usage

qpcr.cbind.na(..., deparse.level = 1)

Value

data frame with NA

Arguments

...

vectors

deparse.level

set to 1 as default

Examples

Run this code
qpcr.cbind.na(1:10, 1:3)

Run the code above in your browser using DataLab