legend_sig_peptides: Legend for the significant peptides
Description
Returns names for legend for the significant peptides plots.
Usage
legend_sig_peptides(ranges = c(-Inf, seq(-30, 30, by = 10), Inf))
Value
legend for the heatmap
Arguments
- ranges
ranges that are to be colored in the legend. Default ranges=c(-Inf,seq(-30, 30, by=10), Inf )