qpcr.cbind.na: Hidden function from qpcR package, typical usage as qpcR:::cbind.na
Description
Combine data of unequal row length avoiding repetition or errors by filling with NAs. In contrast to classical cbind, cbind.na can be used to combine data such as
Usage
qpcr.cbind.na(..., deparse.level = 1)
Arguments
- ...
vectors
- deparse.level
set to 1 as default